@@ -41,9 +41,9 @@ if opts.gtk:
     from sqlkit import debug as dbg
     dbg.debug(True)
     dbg.debug(True, gtk=True)
-    dbg.trace_class(ok='SqlTable|SqlWidget|SqlMask|Completion')
+    dbg.trace_class(ok='SqlTable|SqlWidget|SqlMask|Completion|Field')
     but = 'set_fkey_descr|(lookup|get)_value' + \
-        '|lookup_value|is_fkey'
+        '|lookup_value|is_fkey|type'
     dbg.trace_function(exclude=but)
 
 from demo_tour import Demo
@@ -55,6 +55,22 @@ class MissingExampleError(Exception): pass
 
 def init_db():
 
+    if not os.access( model.DB_FILE, os.O_WRONLY ):
+        # No write access - work in a temporary directory
+        curdir = os.path.realpath( os.curdir )
+        tempdir = model.DB_DIR
+        os.chdir( tempdir )
+        dirs = ['model', 'images']
+        for a_dir in ['model', 'images']:
+            os.mkdir( a_dir )
+            for something in os.listdir( os.path.join( curdir, a_dir ) ):
+                real_path = os.path.join (curdir, a_dir, something )
+                os.symlink( real_path, os.path.join( a_dir, something ) )
+        for something in os.listdir( curdir ):
+            if something in dirs:
+                continue
+            real_path = os.path.join( curdir, something )
+            os.symlink( real_path, something )
     with closing(sqlite3.connect(model.DB_FILE)) as db:
         with open('model/schema.sql', 'r') as schema:
             db.cursor().executescript(schema.read())
@@ -163,11 +179,16 @@ if __name__ == '__main__':
             print "This version of gtk doesn't have 'set_interactive', sorry."
             sys.exit(1)
         try:
-            import IPython
-            from IPython.Shell import IPShellEmbed
-            ipshell = IPShellEmbed([])
             print "The last opened table is hold in variable 'd.t' (i.e.: demo.table)"
-            ipshell()
+            import IPython
+            shell = IPython.Shell.IPShell(argv=[])
+            shell.mainloop()
+            # from IPython.Shell import IPShellEmbed
+            # ipshell = IPShellEmbed([])
+            # ipshell()
+        except AttributeError, e:
+            from IPython import embed
+            embed()
         except ImportError, e:
             print "Interactive demo needs ipython. Quitting."
     else:
