@@ -1,7 +1,7 @@
-"""hooks/on_field_validation
+"""hooks/on_field_validation on_save_as
 
 you can set hooks on single field validation. It will be called from within
-the field 
+the field. The hook 'on_save_as' is called when a record is duplicated.
 
 
 """
@@ -13,6 +13,9 @@ class Hooks(object):
         if field_value > 2020:
             raise ValidationError("Hei: how can you know the future!")
 
+    def on_save_as(self, mask, old, new):
+        print "Old title: %s, \nnew title: %s" % (old.title, new.title)
+
 
 lay = """
    title
