@@ -20,10 +20,20 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 # USA
 
-# Todo:
-#
-# mnemonic stuff
-# gobject register no longer needed...
+"""
+.. _date_edit:
+
+DateEdit
+========
+
+.. autoclass:: DateEdit
+   :members: __init__, get_date, set_date
+
+.. autoclass:: DateTimeEdit
+   :members: __init__, get_datetime, set_datetime
+   
+"""
+
 
 
 import sys
@@ -34,10 +44,11 @@ import locale
 import datetime
 
 import pygtk
-#pygtk.require('2.0')
+pygtk.require('2.0')
 import gobject
 import gtk
 from gtk import gdk
+from babel import dates
 
 from sqlkit import _
 
@@ -53,6 +64,9 @@ class WrongDateFormat(Exception): pass
  #
  # Returns: a new #GnomeDateEdit widget. 
 class DateEdit(gtk.HBox):
+    """
+    basic gtk widget to edit data
+    """
     __gtype_name__ = 'DateEdit'
     
     __gproperties__ = {
@@ -61,15 +75,20 @@ class DateEdit(gtk.HBox):
                     'The date currently selected',             # description
                     gobject.PARAM_READWRITE),                  # flags
 
-        'initial_date' : (gobject.TYPE_PYOBJECT,
+        'initial-date' : (gobject.TYPE_PYOBJECT,
                     'Initial Date',
                     'The initial date',
                     gobject.PARAM_READABLE),
+
+        'width-chars' : (gobject.TYPE_PYOBJECT,
+                    'Width of the entry in chars',
+                    'The width of the entry',
+                    gobject.PARAM_READWRITE),
                   
     }
 
     __gsignals__ = {
-        'date_changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+        'date-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
                           ()),                          
     }
 
@@ -81,11 +100,14 @@ class DateEdit(gtk.HBox):
         self.invalid_date = False
         #datetime.datetime.today()
 
-        self.locale_setup()
+        try:
+            self.locale_setup()
+        except locale.Error:
+            pass
         self.build_layout()
-        
-        self._date_entry.connect('leave-notify-event', self.date_entry_focus_out_event_cb)
-#        self._date_entry.connect('focus-out-event', self.date_entry_focus_out_event_cb)
+
+        hid = self._date_entry.connect('changed', self.date_entry_changed_cb)
+        self._ids = {'date_entry_changed' : (self._date_entry, hid)}
         self._date_button.connect('clicked', self.date_button_clicked_cb)
 
         self._calendar.connect('day-selected', self.day_selected_cb)
@@ -94,12 +116,14 @@ class DateEdit(gtk.HBox):
         self._cal_popup.connect('delete_event', self.delete_popup_cb)
         self._cal_popup.connect('key_press_event', self.key_press_popup_cb)
            
-        self.date_format = '%x'
-
+        self.date_format = 'short'
+        self.date_parse = None
+        self._id_timeout_add = None
+        
     def locale_setup(self):
         if os.name == 'nt' or sys.platform == 'darwin':
             # Todo: fix this for windows
-            self.__use_24h_format = False
+            self._use_24h_format = False
         else:
             # locale stuff, ugly hack, due to ugly locale functions
             saved_locale = locale.getlocale()
@@ -108,9 +132,9 @@ class DateEdit(gtk.HBox):
                 locale.setlocale(locale.LC_ALL, '')
             # the time format
             if locale.nl_langinfo(locale.T_FMT_AMPM) == '' :
-                self.__use_24h_format = True
+                self._use_24h_format = True
             else:
-                self.__use_24h_format = False
+                self._use_24h_format = False
             # restore original locale
             locale.setlocale(locale.LC_ALL, saved_locale)
         
@@ -127,9 +151,10 @@ class DateEdit(gtk.HBox):
         self._entry = self._date_entry
         self._date_entry.set_max_length(15)
         self._date_entry.set_width_chars(10)
-        self._align_entry = gtk.Alignment(1,0,1,0)
+        self._align_entry = gtk.Alignment(0,0)
         #self.pack_start(self._date_entry, True, True, 0)
         date_box.add(self._align_entry)
+        date_box.child_set_property(self._align_entry, 'expand', False)
         self._align_entry.add(self._date_entry)
         self._align_entry.show()
         self._date_entry.show()
@@ -162,6 +187,8 @@ class DateEdit(gtk.HBox):
         self._cal_popup.set_title('popup for calendar')
         self._cal_popup.set_events(self._cal_popup.get_events() | gdk.KEY_PRESS_MASK)
         self._cal_popup.set_resizable(False) # Todo: Needed?
+        self._cal_popup.set_tooltip_text(_(
+            'Press Esc to close or double click a date to select it'))
 
         frame = gtk.Frame()
         frame.set_shadow_type(gtk.SHADOW_OUT)
@@ -193,18 +220,18 @@ class DateEdit(gtk.HBox):
         self._default_base = color
         
     def popup_grab_on_window(self, window, activate_time):
-        if gdk.pointer_grab(window, True, gdk.BUTTON_PRESS_MASK 
+        grab = gdk.pointer_grab(window, True, gdk.BUTTON_PRESS_MASK 
                                           | gdk.BUTTON_RELEASE_MASK
                                           | gdk.POINTER_MOTION_MASK, 
-                            None, None, activate_time) == 0:
-                if gdk.keyboard_grab (window, True, activate_time) == 0:
-                    return True
-                else:
-                    gdk.pointer_ungrab(activate_time)
-                    return False
+                            None, None, activate_time)
+        if grab == 0:
+            if gdk.keyboard_grab (window, True, activate_time) == 0:
+                return True
+            else:
+                gdk.pointer_ungrab(activate_time)
+                return False
         return False
 
-
     def position_popup(self):
         req = self._cal_popup.size_request()
         (x,y) = gdk.Window.get_origin(self._date_button.window)
@@ -229,19 +256,38 @@ class DateEdit(gtk.HBox):
         
         
 #####  callback
-    def date_entry_focus_out_event_cb(self, widget, event):
-        # check entry for valid date, reset if not
+    def date_entry_changed_cb(self, entry):
+        # check entry for valid date 
+        if self._id_timeout_add:
+            gobject.source_remove(self._id_timeout_add)
+        
+        # let's delay the check so we can complete our input
+        self._id_timeout_add = gobject.timeout_add(700, self.verify_date, entry)
+
+    def verify_date(self, entry):
+        """Verify the text anc heck if it parses as date, complain if not
+        """
         date_string = self._date_entry.get_text()
         if not date_string:
             self.set_date(None)
-            return
+            return False
         try:
-            new_date = time.strptime(date_string, self.date_format)
-            the_date = datetime.date(new_date.tm_year,new_date.tm_mon,new_date.tm_mday,)
-            self.set_date(the_date, from_focus_out=True)
-        except ValueError, e:
+            if callable(self.date_parse):
+                the_date = self.date_parse(date_string)
+            else:
+                the_date = dates.parse_date(date_string)
+        except Exception, e:
             self.wrong_date_format(e, date_string)
- 
+            return False
+
+        try:
+            self.set_date(the_date, from_focus_out=True)
+        except Exception, e:
+            print e
+            return False
+        entry.modify_base(gtk.STATE_NORMAL, self._default_base)
+        return False
+
     def date_button_clicked_cb(self, widget):
         # Temporarily grab pointer and keyboard on a window we know exists        
         if not self.popup_grab_on_window(widget.window, gtk.get_current_event_time()):
@@ -290,7 +336,10 @@ class DateEdit(gtk.HBox):
 ####### date & gobject
     def wrong_date_format(self, error, date_string):
         self.invalid_date = True
-        self.flash_bg(self._date_entry, 'orangered', 2)
+        colormap = self._date_entry.get_colormap()
+        base_color = colormap.alloc_color('orangered')
+        self._date_entry.modify_base(gtk.STATE_NORMAL, base_color)
+        #self.flash_bg(self._date_entry, 'orangered', 2)
         
     def get_date(self):
 
@@ -319,10 +368,22 @@ class DateEdit(gtk.HBox):
         self.invalid_date = False
         
         # set the time and date string
+        entry, hid = self._ids['date_entry_changed']
+        entry.handler_block(hid)
+
         if new_date:
-            self._date_entry.set_text(new_date.strftime(self.date_format))
+            if callable(self.date_format):
+                try:
+                    self._date_entry.set_text(self.date_format(new_date))
+                except:
+                    self._date_entry.set_text(
+                        dates.format_date(new_date, format='short'))
+            else:
+                self._date_entry.set_text(
+                    dates.format_date(new_date, format=self.date_format))
         else:
             self._date_entry.set_text('')
+        entry.handler_unblock(hid)
 
         if date_changed:
             self._current_date = new_date
@@ -335,6 +396,8 @@ class DateEdit(gtk.HBox):
             return self.get_date()
         elif property.name == 'initial-date':
             return self._initial_date
+        elif property.name == 'width-chars':
+            return self._date_entry.props.width_chars
         else:
             raise AttributeError, 'unknown property %s' % property.name
 
@@ -342,6 +405,8 @@ class DateEdit(gtk.HBox):
     def do_set_property(self, property, value):
         if property.name == 'date':
             self.set_date(value)
+        elif property.name == 'width-chars':
+            self._date_entry.props.width_chars = value
         else:
             raise AttributeError, 'unknown property %s' % property.name
             
@@ -384,6 +449,7 @@ class DateTimeEdit(DateEdit):
                     True,
                     gobject.PARAM_READWRITE),
                     
+        # TODO: use-24 is not working, only 24 hours is working
         'use-24h-format' : (gobject.TYPE_BOOLEAN,
                     'Use 24h Format',
                     'Display time in 24h format',
@@ -392,28 +458,25 @@ class DateTimeEdit(DateEdit):
         }
 
     __gsignals__ = {
-        'datetime_changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+        'datetime-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
                           ()),
-        'time_changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+        'time-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
                           ()),
         }
     def __init__(self):
 
         # preset values
         self._initial_datetime = self._current_datetime = None
-        #datetime.datetime.today()
         self._lower_hour = 7;
         self._upper_hour = 19;        
         self._show_time = True
         self._use_24h_format = True
         
         DateEdit.__init__(self)
-        
         self._time_combobox.connect('changed', self.time_combobox_changed_cb)
         self._time_combobox.child.connect('focus-out-event', self.time_entry_focus_out_event_cb)
         self.connect('realize', self.fill_time_combobox)
 
-
     def build_layout(self):
 
         DateEdit.build_layout(self)
@@ -421,7 +484,6 @@ class DateTimeEdit(DateEdit):
         time_box = gtk.HBox()
         self.add(time_box)
         time_box.show()
-        
 
         # the time entry combobox
         self._time_combobox = gtk.ComboBoxEntry()
@@ -433,7 +495,6 @@ class DateTimeEdit(DateEdit):
            
         # set the initial widget properties
         self.set_show_time(self._show_time)
-#        self.set_time(self._initial_datetime)
         self.set_use_24h_format(self._use_24h_format)
 
     def fill_time_combobox(self, widget, data=None):
@@ -487,6 +548,7 @@ class DateTimeEdit(DateEdit):
 
         except Exception, e:
             self.wrong_time_format(e, time_text)
+        self.set_time(the_time)
         
     ############################################
     # properties and their convenience functions
@@ -499,8 +561,7 @@ class DateTimeEdit(DateEdit):
         dt = self.get_time()
         self._use_24h_format = use_24h_format
         self.fill_time_combobox(self)
-        self.set_time(dt)
-
+        self._current_time = dt
 
     # get_properties
     def set_lower_hour(self, value):
@@ -579,8 +640,7 @@ class DateTimeEdit(DateEdit):
 
     def set_time(self, new_time, focus=False):
 
-        time_changed =  new_time == self._current_time
-
+        time_changed =  not new_time == self._current_time
         if new_time == None:
             self._time_combobox.child.set_text('')
         else:
@@ -604,15 +664,15 @@ class DateTimeEdit(DateEdit):
         if property.name == 'datetime':
             return self.get_datetime()
         elif property.name == 'initial-datetime':
-            return self.__initial_datetime
+            return self._initial_datetime
         elif property.name == 'lower-hour': 
-            return self.__lower_hour
+            return self._lower_hour
         elif property.name == 'upper-hour':
-            return self.__upper_hour
+            return self._upper_hour
         elif property.name == 'show-time':
-            return self.__show_time
+            return self._show_time
         elif property.name == 'use-24h-format':
-            return self.__use_24h_format
+            return self._use_24h_format
         else:
             raise AttributeError, 'unknown property %s' % property.name
 
@@ -632,30 +692,51 @@ class DateTimeEdit(DateEdit):
         else:
             raise AttributeError, 'unknown property %s' % property.name
             
-# finally register our new Type
-if gobject.pygtk_version < (2, 8):
-	    gobject.type_register(DateEdit)
-	    gobject.type_register(DateTimeEdit)
+
+class EntryCal(gtk.Entry):
+    """
+    basic gtk widget to edit data that uses primary/secondary icon stock
+    """
+    __gtype_name__ = 'DateEdit2'
+    
+    __gproperties__ = {
+        'date' : (gobject.TYPE_PYOBJECT,                       # type
+                    'Date',                                    # nick name
+                    'The date currently selected',             # description
+                    gobject.PARAM_READWRITE),                  # flags
+
+        'initial-date' : (gobject.TYPE_PYOBJECT,
+                    'Initial Date',
+                    'The initial date',
+                    gobject.PARAM_READABLE),
+
+        'width-chars' : (gobject.TYPE_PYOBJECT,
+                    'Width of the entry in chars',
+                    'The width of the entry',
+                    gobject.PARAM_READWRITE),
+                  
+    }
+
+    __gsignals__ = {
+        'date-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+                          ()),                          
+    }
+
+    def __init__(self):
+        
+        gtk.Entry.__init__(self)
+        self.props.primary_icon_stock = 'gtk-quit'
+        self.props.secondary_icon_stock = 'sk-calendar'
+        self.props.secondary_icon_tooltip_text = "Calendar"
 
 if __name__ == '__main__':
 
+    import misc  # adds the sk-calendar stock-icon
     w = gtk.Window()
-    v = gtk.VBox()
-    d1 = DateTimeEdit()
-    d2 = DateTimeEdit()
-    d3 = DateEdit()
-    d2.set_property('show_time', False)
-    v.add(d1)
-    v.add(d2)
-    v.add(d3)
-#    d1.set_property('datetime', None)
-    d1.set_property('datetime', datetime.datetime.now())
-    d3.set_property('date', datetime.date.today())
-    d3.set_property('date', None)
-    w.add(v)
+    d = EntryCal()
+#    d = DateTimeEdit()
+    w.add(d)
     w.show_all()
 
-    gtk.main()
+    gtk.set_interactive(True)
     
-
-
