@@ -28,7 +28,7 @@ import pango
 import gobject
 from babel import numbers
 import sqlalchemy
-from sqlalchemy import exceptions, Table, orm
+from sqlalchemy import Table, orm
 from sqlalchemy.orm import scoped_session, sessionmaker, class_mapper, attributes
 from sqlalchemy.exc import InvalidRequestError
 from sqlalchemy.orm.mapper import Mapper
@@ -387,7 +387,7 @@ class SqlWidget(gobject.GObject):
             try:
                 session._sk_emitter.add(self)
             except AttributeError:
-                warning.warn("Session does not have '_sk_emitter', signals after-flush "
+                warnings.warn("Session does not have '_sk_emitter', signals after-flush "
                              "after-commit and after-flush-postexec are not implemented")
             
         return session
@@ -765,12 +765,12 @@ class SqlWidget(gobject.GObject):
     
     def get_table_labels(self):
         """
-        get labels and tips from the db is they exists
+        get labels and tips from the db if they exists
         """
         from sqlkit.db.utils import get_labels_and_tips_from_sqlkit
         if self.tables:
             for table in [t.name for t in self.mapper.tables]:
-                self.label_map.update( get_labels_and_tips_from_sqlkit(table, metadata=self.metadata))
+                self.label_map.update( get_labels_and_tips_from_sqlkit(table, metadata=self.metadata, class_=self.mapper.class_))
             
     def resize(self, width, height):
         """
@@ -1024,7 +1024,7 @@ class SqlWidget(gobject.GObject):
             self.run_hook('on_record_saved')
             self.sb(message, seconds=3)
 
-        except (exceptions.DBAPIError, exceptions.FlushError), e:
+        except (sqlalchemy.exc.DBAPIError, sqlalchemy.exc.FlushError), e:
             if not self.commit_error_handler(e):
                 self.session.rollback()
                 raise exc.HandledRollback(str(e))
@@ -1034,13 +1034,13 @@ class SqlWidget(gobject.GObject):
         communicate the problem to the user
         return True to prevent rollback
         """
-        if isinstance(e, exceptions.IntegrityError):
+        if isinstance(e, sqlalchemy.exc.IntegrityError):
             # TIP: message in the status bar when a commit error is handled
             msg = _("Error while writing to the database. \nOriginal error was: \n%s") % e
             self.message(type='error', text=_(msg))
             self.sb(str(e))
 
-        elif isinstance(e, exceptions.ProgrammingError):
+        elif isinstance(e, sqlalchemy.exc.ProgrammingError):
             # TIP: Error while saving into a table w/o permission
             msg = _("A programming error was received from the backend:\n%s") % e
             if re.search('permission denied', msg, re.I):
@@ -1048,14 +1048,14 @@ class SqlWidget(gobject.GObject):
             self.message(type='error', text=msg)
             self.sb(e.orig)
 
-        elif isinstance(e, exceptions.DBAPIError):
+        elif isinstance(e, sqlalchemy.exc.DBAPIError):
             # TIP: message in the status bar when a commit error is handled
             self.message(type='error',
                          text=_("%s - Dirty objects: %s - New objects: %s") % \
                          (str(e.orig),len(self.session.dirty),len(self.session.new)))
             self.sb(e.orig)
 
-        elif isinstance(e, exceptions.FlushError):
+        elif isinstance(e, sqlalchemy.exc.FlushError):
             # TIP: message in the status bar when a commit error is handled
             msg = _("Error while writing to the database: \n" \
                     "are you 'saving as new' an already known record?\n" + \
@@ -1154,7 +1154,7 @@ class SqlWidget(gobject.GObject):
             dialog = UnsavedDataDialog(self)
             response = dialog.run()
 
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 pass
 
             if response == gtk.RESPONSE_YES:
@@ -1542,10 +1542,14 @@ class SqlWidget(gobject.GObject):
         sql may be a tuple (sql_statement, bind_params) or just a sql_statement
         """
         from sqlkit.db.django_syntax import django2query
+        
         if limit:
             self.limit = limit
 
-        query = self.query.filter(None)
+        try:
+            query = self.query.filter()
+        except TypeError: # SQLAlchemy < 0.7.8
+            query = self.query.filter(None)
 
         ## order_by
         if order_by:
@@ -1577,7 +1581,7 @@ class SqlWidget(gobject.GObject):
             self.clear(check=False)
         try:
             self.records = query.all()
-        except exceptions.ProgrammingError, e:
+        except sqlalchemy.exc.ProgrammingError, e:
             # TIP: reloading data from the database
             msg = _("A programming error was received from the backend:\n%s") % e
             if re.search('permission denied', msg, re.I):
@@ -1585,7 +1589,7 @@ class SqlWidget(gobject.GObject):
             self.message(type='error', text=msg)
             self.sb(e.orig)
             return
-        except exceptions.InterfaceError, e:
+        except sqlalchemy.exc.InterfaceError, e:
             ## the connection may be closed and a retry could restore it
             if re.search('closed', str(e), re.I):
                 self.records = query.all()
@@ -2055,10 +2059,10 @@ class SqlWidget(gobject.GObject):
             return self.widgets['Window']
         except KeyError, e:
             try:
+                return self.widgets['T.0'].get_toplevel()
+            except KeyError, e:
                 return self.relationship_leader.get_toplevel()
-            except AttributeError, e:
-                return None
-        
+    
     def fkey_is_valid(self):
         """
         return True if current editable -if exists- has a value that does not need validation
@@ -2395,7 +2399,7 @@ class ValidationWarningDialog(ValidationErrorDialog):
         self.dialog.destroy()
 
         self.error_dict = {}
-        if response == gtk.RESPONSE_CANCEL:
+        if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
             raise exc.DialogValidationError
         else:
             pass
