@@ -81,7 +81,7 @@ class SqlMask(sqlwidget.SqlWidget):
         """
         add mouse wheel support
         """
-        if not self.widgets['Window']:
+        if not 'Window' in self.widgets:
             return
             
         def scroll_event_cb(widget, event):
@@ -419,7 +419,7 @@ class SqlMask(sqlwidget.SqlWidget):
             self.session.add(obj)
 
         # mask2obj ensures that the object used for validation is updated from the mask
-        # record_valildate that is run just after mask2object requires validation_errors/warnings
+        # record_validate that is run just after mask2obj requires validation_errors/warnings
         # be present
         self.validation_errors = {}
         self.validation_warnings = {}
@@ -478,7 +478,7 @@ class SqlMask(sqlwidget.SqlWidget):
         if ask:
             response = self.save_unsaved(skip_check=True, proceed=False)
 
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 raise exc.CancelledAction
 
             if response == gtk.RESPONSE_NO: 
@@ -533,13 +533,13 @@ class SqlMask(sqlwidget.SqlWidget):
                   "Read the docs for more informations"
             response = self.dialog(type='ok-cancel', text=_(msg) % o2m_list,
                                    icon='gtk-dialog-warning')
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 return
         elif ask:
             msg = _("Do you want to copy all data to a new record?")
             response = self.dialog(type='ok-cancel', text=_(msg) % o2m_list,
                                    icon='gtk-dialog-question')
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 return
             
         records_m2m = {}
@@ -586,7 +586,7 @@ class SqlMask(sqlwidget.SqlWidget):
         if interactive:
             text = _("Delete this record?\n(%s)") % self.current
             response = self.dialog(type='ok-cancel', text=text)
-            if response == gtk.RESPONSE_CANCEL:
+            if response != gtk.RESPONSE_OK:
                 return
         obj = self.records[self.current_idx]
         if obj in self.session.new:
@@ -630,7 +630,7 @@ class SqlMask(sqlwidget.SqlWidget):
             skip_new = self.current
             
         response = self.save_unsaved(skip_check=changed, skip_new=skip_new)
-        if response == gtk.RESPONSE_CANCEL:
+        if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
             return
             
         self.current_idx = 0
