@@ -832,7 +832,7 @@ class SqlTable(sqlwidget.SqlWidget):
         if ask:
             response = self.save_unsaved(skip_check=skip_check, proceed=False)
 
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 raise exc.CancelledAction
 
             if response == gtk.RESPONSE_NO: 
@@ -996,7 +996,7 @@ class SqlTable(sqlwidget.SqlWidget):
             if model.iter_has_child(iter):
                 text += "\n" + _("All children will be deleted as well") 
             response = self.dialog(type='ok-cancel', text=text)
-            if response == gtk.RESPONSE_CANCEL:
+            if response != gtk.RESPONSE_OK:
                 return
 
         self.deleting_row = True
@@ -1137,7 +1137,7 @@ class SqlTable(sqlwidget.SqlWidget):
                 show = self.gui_fields[field_name].widget.completion.show_possible_completion
                 show(self.cell_entry.entry, 'start')
                 return True
-            except (sqlalchemy.exceptions.DBAPIError), e:
+            except (sqlalchemy.exc.DBAPIError), e:
                 self.sb(e)
                 return True
         else:
@@ -1277,7 +1277,7 @@ class SqlTable(sqlwidget.SqlWidget):
         self._new_record = False
 
 
-    def record_in_mask(self, widget=None):
+    def record_in_mask(self, widget=None, addto=None, naked=False):
         """
         Open a SqlMask to show self.current if any and to follow selection.
         
@@ -1305,7 +1305,7 @@ class SqlTable(sqlwidget.SqlWidget):
             self._mask().widgets['Window'].present()
             return
         mask = SqlMask(self.mapper, session=self.session, layout=self.layout,
-                       metadata=self.metadata, dbproxy=self.dbproxy, hooks=self.hooks)
+                       metadata=self.metadata, dbproxy=self.dbproxy, hooks=self.hooks, addto=None, naked=False)
         mask.set_mode(self.mode, reset=True)
         mask.mode = '-bd'
         obj = getattr(self, '_clicked_obj', self.get_selected_obj())
@@ -1424,13 +1424,13 @@ class SqlTable(sqlwidget.SqlWidget):
         self.select_path(self._clicked_path)
         save_path = self.gui_fields[field_name].get_save_path(
                         name=dialog.new_filename or filename,
-                        obj=self.current)
+                        obj=self.current, new=True)
         if os.path.exists(save_path):
             response = self.dialog(
                 type="ok-cancel",
                 text=_("A file with name '%s' already exists.\nOverwrite?") % save_path,
                 title=_('Upload name duplication'))
-            if response == gtk.RESPONSE_CANCEL:
+            if response in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 return
 
         self.gui_fields[field_name].widget.copy_file = filename # delay the real copy
